==> duiba-stock-service-api-0.0.2-20220207.072139-28-sources.jar: cn/com/duiba/cloud/stock/service/api/param/occupy/EditOccupyStockParam.java <==
package cn.com.duiba.cloud.stock.service.api.param.occupy;

import cn.com.duiba.cloud.stock.service.api.enums.stock.StockOccupyEnum;
import cn.com.duiba.cloud.stock.service.api.param.BaseAppParam;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

import javax.validation.constraints.NotNull;
import java.io.Serializable;
import java.util.List;

/**
 * 编辑预占库存请求参数
 *
 * @author zhoujunquan@duiba.com.cn
 * @version 1.0
 * @date 2021/12/25 2:29 下午
 **/
@Data
@Accessors(chain = true)
@EqualsAndHashCode(callSuper = true)
public class EditOccupyStockParam extends BaseAppParam implements Serializable {
    private static final long serialVersionUID = 4662189102105166726L;

    /**
     * 调度作用域id 如活动id
     */
    @NotNull(message = "预占泛id不能为空")
    private Long generalId;

    /**
     * 调度作用域类型 {@link StockOccupyEnum}
     */
    @NotNull(message = "预占类型不能为空")
    private Integer generalType;

    /**
     * 新增预占库存参数
     */
    private List<AddOccupyStockParam> addOccupyStockParamList;

    /**
     * 变更预占库存参数
     */
    private List<ChangeOccupyStockParam> changeOccupyStockParamList;

    /**
     * 清除的skuId列表
     */
    private List<Long> cleanSkuIdList;

    @Data
    @Accessors(chain = true)
    public static class AddOccupyStockParam implements Serializable {
        private static final long serialVersionUID = 7022743239494569623L;

        /**
         * skuId
         */
        @NotNull(message = "skuId不能为空")
        private Long skuId;

        /**
         * 调度值
         */
        private Long dispatchValue;
    }

    @Data
    @Accessors(chain = true)
    public static class ChangeOccupyStockParam implements Serializable {
        private static final long serialVersionUID = -2711808867874266700L;

        /**
         * skuId
         */
        @NotNull(message = "skuId不能为空")
        private Long skuId;

        /**
         * 更新值
         */
        private Long changeValue;
    }
}

==> duiba-stock-service-api-0.0.3-20220302.093710-4-sources.jar: cn/com/duiba/cloud/stock/service/api/param/occupy/EditOccupyStockParam.java <==
package cn.com.duiba.cloud.stock.service.api.param.occupy;

import cn.com.duiba.cloud.stock.service.api.enums.stock.StockOccupyEnum;
import cn.com.duiba.cloud.stock.service.api.param.BaseAppParam;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

import javax.validation.Valid;
import javax.validation.constraints.Min;
import javax.validation.constraints.NotNull;
import java.io.Serializable;
import java.util.List;

/**
 * 编辑预占库存请求参数
 *
 * @author zhoujunquan@duiba.com.cn
 * @version 1.0
 * @date 2021/12/25 2:29 下午
 **/
@Data
@Accessors(chain = true)
@EqualsAndHashCode(callSuper = true)
public class EditOccupyStockParam extends BaseAppParam implements Serializable {
    private static final long serialVersionUID = 4662189102105166726L;

    /**
     * 调度作用域id 如活动id
     */
    @NotNull(message = "预占泛id不能为空")
    private Long generalId;

    /**
     * 调度作用域类型 {@link StockOccupyEnum}
     */
    @NotNull(message = "预占类型不能为空")
    private Integer generalType;

    /**
     * 新增预占库存参数
     */
    @Valid
    private List<AddOccupyStockParam> addOccupyStockParamList;

    /**
     * 变更预占库存参数
     */
    @Valid
    private List<ChangeOccupyStockParam> changeOccupyStockParamList;

    /**
     * 清除的skuId列表
     */
    private List<Long> cleanSkuIdList;

    @Data
    @Accessors(chain = true)
    public static class AddOccupyStockParam implements Serializable {
        private static final long serialVersionUID = 7022743239494569623L;

        /**
         * skuId
         */
        @NotNull(message = "skuId不能为空")
        private Long skuId;

        /**
         * 调度值
         */
        @NotNull(message = "预占库存数量为空或小于0")
        @Min(value = 0, message = "预占库存数量为空或小于0")
        private Long dispatchValue;

        /**
         * sku货主应用id
         */
        @NotNull(message = "sku货主应用id不能为空")
        private Long sourceAppId;
    }

    @Data
    @Accessors(chain = true)
    public static class ChangeOccupyStockParam implements Serializable {
        private static final long serialVersionUID = -2711808867874266700L;

        /**
         * skuId
         */
        @NotNull(message = "skuId不能为空")
        private Long skuId;

        /**
         * 更新值
         */
        @NotNull(message = "变更值为空")
        private Long changeValue;

        /**
         * sku货主应用id
         */
        @NotNull(message = "sku货主应用id不能为空")
        private Long sourceAppId;
    }
}
